/* styles for search components */

.ab-search-input {
  margin-bottom: 2em;
}

.ab-search-results {
}

.ab-search-result {
  padding-bottom: 1em;

  .title {
    font-size: 1.25em;
    font-weight: bold;
  }

  .tags {
    margin-top: 0.5em;
  }

  .snippet {
  }

  .metadata {
  }
}
