""" Application settings service
"""
from __future__ import print_function
from __future__ import division
from __future__ import absolute_import

from .service import SettingsService
from .models import register

__all__ = ['SettingsService', 'register']
